tlslite.messages.ClientHello

Package tlslite :: Module messages :: Class ClientHello |
[hide private]
[frames] | no frames]

# Class ClientHello

source code

    HandshakeMsg --+
                   |
                  ClientHello

Instance Methods | [hide private]
__init__(self, ssl2=False) | source code
create(self, version, random, session_id, cipher_suites, certificate_types=None, srp_username=None, tack=False, supports_npn=False, server_name=`'````'`) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self, ssl2=False) (Constructor) | source code
Overrides: HandshakeMsg.__init__